@@ -5,8 +5,9 @@ import re
 import shlex
 import subprocess
 import sys
-from typing import List, Union
+from typing import Dict, List, Optional, Union
 
+from pdm.cli.actions import PEP582_PATH
 from pdm.cli.commands.base import BaseCommand
 from pdm.exceptions import PdmUsageError
 from pdm.iostream import stream
@@ -16,7 +17,7 @@ from pdm.project import Project
 class Command(BaseCommand):
     """Run commands or scripts with local packages loaded"""
 
-    OPTIONS = ["env", "help"]
+    OPTIONS = ["env", "env_file", "help"]
     TYPES = ["cmd", "shell", "call"]
 
     def add_arguments(self, parser: argparse.ArgumentParser) -> None:
@@ -26,6 +27,12 @@ class Command(BaseCommand):
             action="store_true",
             help="Show all available scripts defined in pyproject.toml",
         )
+        parser.add_argument(
+            "-s",
+            "--site-packages",
+            action="store_true",
+            help="Load site-packages from system interpreter",
+        )
         parser.add_argument("command", nargs="?", help="The command to run")
         parser.add_argument(
             "args",
@@ -37,9 +44,22 @@ class Command(BaseCommand):
     def _run_command(
         project: Project,
         args: Union[List[str], str],
-        shell=False,
-        env=None,
+        shell: bool = False,
+        env: Optional[Dict[str, str]] = None,
+        env_file: Optional[str] = None,
     ) -> None:
+        if "PYTHONPATH" in os.environ:
+            new_path = os.sep.join([PEP582_PATH, os.getenv("PYTHONPATH")])
+        else:
+            new_path = PEP582_PATH
+        os.environ.update({"PYTHONPATH": new_path})
+        if env_file:
+            import dotenv
+
+            stream.echo(f"Loading .env file: {stream.green(env_file)}", err=True)
+            dotenv.load_dotenv(
+                project.root.joinpath(env_file).as_posix(), override=True
+            )
         if env:
             os.environ.update(env)
         if shell:
@@ -86,7 +106,13 @@ class Command(BaseCommand):
             )
         return kind, value, options
 
-    def _run_script(self, project: Project, script_name: str, args: List[str]) -> None:
+    def _run_script(
+        self,
+        project: Project,
+        script_name: str,
+        args: List[str],
+        global_env_options: Dict[str, Union[str, Dict[str, str]]],
+    ) -> None:
         script = project.scripts[script_name]
         kind, value, options = self._normalize_script(script)
         if kind == "cmd":
@@ -109,6 +135,11 @@ class Command(BaseCommand):
                 f"import sys, {module} as {short_name};"
                 f"sys.exit({short_name}.{func})",
             ] + args
+        if "env" in global_env_options:
+            options["env"] = {**global_env_options["env"], **options.get("env", {})}
+        options["env_file"] = options.get(
+            "env_file", global_env_options.get("env_file")
+        )
         stream.echo(f"Running {kind} script: {stream.green(str(args))}", err=True)
         return self._run_command(project, args, **options)
 
@@ -118,6 +149,8 @@ class Command(BaseCommand):
         columns = ["Name", "Type", "Script", "Description"]
         result = []
         for name, script in project.scripts.items():
+            if name == "_":
+                continue
             kind, value, options = self._normalize_script(script)
             result.append((stream.green(name), kind, value, options.get("help", "")))
         stream.display_columns(result, columns)
@@ -125,8 +158,12 @@ class Command(BaseCommand):
     def handle(self, project: Project, options: argparse.Namespace) -> None:
         if options.list:
             return self._show_list(project)
-        with project.environment.activate():
-            if project.scripts and options.command in project.scripts:
-                self._run_script(project, options.command, options.args)
-            else:
-                self._run_command(project, [options.command] + options.args)
+        global_env_options = project.scripts.get("_", {}) if project.scripts else {}
+        if options.site_packages:
+            os.environ.update({"PDM_WITH_SITE_PACKAGES": "1"})
+        if project.scripts and options.command in project.scripts:
+            self._run_script(project, options.command, options.args, global_env_options)
+        else:
+            self._run_command(
+                project, [options.command] + options.args, **global_env_options
+            )
