@@ -9,7 +9,7 @@ from pip._vendor.pkg_resources import EggInfoDistribution
 from pip_shims import shims
 
 from pdm.iostream import stream
-from pdm.models.builders import log_subprocessor
+from pdm.models.builders import EnvBuilder
 from pdm.models.requirements import parse_requirement
 
 if TYPE_CHECKING:
@@ -32,13 +32,6 @@ def format_dist(dist: Distribution) -> str:
     return formatter.format(version=stream.yellow(dist.version), path=path)
 
 
-EXE_INITIALIZE = """
-import sys
-with open({0!r}) as fp:
-    exec(compile(fp.read(), __file__, "exec"))
-""".strip()
-
-
 class Installer:  # pragma: no cover
     """The installer that performs the installation and uninstallation actions."""
 
@@ -59,14 +52,6 @@ class Installer:  # pragma: no cover
         paths = self.environment.get_paths()
         maker = distlib.scripts.ScriptMaker(None, None)
         maker.executable = self.environment.python_executable
-        if not self.environment.is_global:
-            site_custom_script = (
-                self.environment.packages_path / "site/sitecustomize.py"
-            ).as_posix()
-            maker.script_template = maker.script_template.replace(
-                "import sys",
-                EXE_INITIALIZE.format(site_custom_script),
-            )
         wheel.install(paths, maker)
 
     def install_editable(self, ireq: shims.InstallRequirement) -> None:
@@ -84,9 +69,12 @@ class Installer:  # pragma: no cover
             paths["purelib"],
             paths["scripts"],
         ]
-        with self.environment.activate(True):
+        with EnvBuilder(ireq.unpacked_source_directory, self.environment) as builder:
+            builder.install(["setuptools"])
             extra_env = {"INJECT_SITE": "1"} if not self.environment.is_global else None
-            log_subprocessor(install_args, ireq.unpacked_source_directory, extra_env)
+            builder.subprocess_runner(
+                install_args, ireq.unpacked_source_directory, extra_env
+            )
 
     def uninstall(self, dist: Distribution) -> None:
         req = parse_requirement(dist.project_name)
