@@ -24,8 +24,8 @@ def test_sync_only_different(project, repository, working_set, capsys):
     working_set.add_distribution(make_distribution("idna", "2.7"))
     actions.do_add(project, packages=["requests"])
     out, _ = capsys.readouterr()
-    assert "4 packages are installed" in out
-    assert "1 package is updated" in out
+    assert "4 to add" in out
+    assert "1 to update" in out
     assert "foo" in working_set
     assert "test-project" in working_set
     assert working_set["chardet"].version == "3.0.4"
@@ -35,7 +35,7 @@ def test_sync_in_sequential_mode(project, repository, working_set, capsys):
     project.project_config["parallel_install"] = False
     actions.do_add(project, packages=["requests"])
     out, _ = capsys.readouterr()
-    assert "6 packages are installed" in out
+    assert "6 to add" in out
     assert "test-project" in working_set
     assert working_set["chardet"].version == "3.0.4"
 
@@ -205,7 +205,7 @@ def test_update_all_packages(project, repository, working_set, capsys):
     assert locked_candidates["chardet"].version == "3.0.5"
     assert locked_candidates["pytz"].version == "2019.6"
     out, _ = capsys.readouterr()
-    assert "3 packages are updated" in out
+    assert "3 to update" in out
 
     actions.do_sync(project)
     out, _ = capsys.readouterr()
@@ -326,7 +326,7 @@ def test_list_packages(capsys):
     out, _ = capsys.readouterr()
     assert "pdm" in out
     assert "tomlkit" in out
-    assert "halo" in out
+    assert "pip" in out
 
 
 def test_lock_dependencies(project, repository):
