@@ -1,20 +1,53 @@
 import json
 import os
+import subprocess
 import textwrap
 
+import pytest
+
+from pdm.cli.actions import PEP582_PATH
 from pdm.utils import cd, temp_environ
 
 
 def test_pep582_not_loading_site_packages(project, invoke, capfd):
-    invoke(
-        ["run", "python", "-c", "import sys,json;print(json.dumps(sys.path))"],
-        obj=project,
-    )
+    with cd(project.root):
+        invoke(["install"], obj=project)
+        invoke(
+            ["run", "python", "-c", "import sys,json;print(json.dumps(sys.path))"],
+            obj=project,
+        )
     sys_path = json.loads(capfd.readouterr()[0])
     assert not any("site-packages" in p for p in sys_path)
     assert str(project.environment.packages_path / "lib") in sys_path
 
 
+@pytest.mark.pypi
+def test_pep582_launcher_for_python_interpreter(project, invoke):
+    project.tool_settings["python_requires"] = ">=3.6"
+    project.write_pyproject()
+    project.root.joinpath("main.py").write_text(
+        "import requests\nprint(requests.__version__)\n"
+    )
+    invoke(["add", "requests==2.24.0"], obj=project)
+    env = os.environ.copy()
+    env.update({"PYTHONPATH": PEP582_PATH})
+    output = subprocess.check_output(
+        [project.environment.python_executable, str(project.root.joinpath("main.py"))],
+        env=env,
+    )
+    assert output.decode().strip() == "2.24.0"
+
+
+def test_pep582_launcher_with_system_site_packages(project, invoke):
+    with cd(project.root):
+        invoke(["install"], obj=project)
+        result = invoke(["run", "python", "-c", "import resolvelib"], obj=project)
+        assert result.exit_code != 0
+
+        result = invoke(["run", "-s", "python", "-c", "import resolvelib"], obj=project)
+        assert result.exit_code == 0
+
+
 def test_run_command_not_found(invoke):
     result = invoke(["run", "foobar"])
     assert "Command 'foobar' is not found on your PATH." in result.stderr
@@ -126,6 +159,35 @@ def test_run_script_with_env_defined(project, invoke, capfd):
         assert capfd.readouterr()[0].strip() == "bar"
 
 
+def test_run_script_with_dotenv_file(project, invoke, capfd):
+    (project.root / "test_script.py").write_text("import os; print(os.getenv('FOO'))")
+    project.tool_settings["scripts"] = {
+        "test_script": {"cmd": "python test_script.py", "env_file": ".env"}
+    }
+    project.write_pyproject()
+    (project.root / ".env").write_text("FOO=bar")
+    capfd.readouterr()
+    with cd(project.root):
+        invoke(["run", "test_script"], obj=project)
+        assert capfd.readouterr()[0].strip() == "bar"
+
+
+def test_run_script_override_global_env(project, invoke, capfd):
+    (project.root / "test_script.py").write_text("import os; print(os.getenv('FOO'))")
+    project.tool_settings["scripts"] = {
+        "_": {"env": {"FOO": "bar"}},
+        "test_env": {"cmd": "python test_script.py"},
+        "test_env_override": {"cmd": "python test_script.py", "env": {"FOO": "foobar"}},
+    }
+    project.write_pyproject()
+    capfd.readouterr()
+    with cd(project.root):
+        invoke(["run", "test_env"], obj=project)
+        assert capfd.readouterr()[0].strip() == "bar"
+        invoke(["run", "test_env_override"], obj=project)
+        assert capfd.readouterr()[0].strip() == "foobar"
+
+
 def test_run_show_list_of_scripts(project, invoke):
     project.tool_settings["scripts"] = {
         "test_cmd": "flask db upgrade",
@@ -134,7 +196,6 @@ def test_run_show_list_of_scripts(project, invoke):
     }
     project.write_pyproject()
     result = invoke(["run", "--list"], obj=project)
-    print(result.output, result.stderr)
     result_lines = result.output.splitlines()[2:]
     assert result_lines[0].strip() == "test_cmd    cmd   flask db upgrade"
     assert (
